@@ -63,7 +63,7 @@ read_grid <- function(city = NULL,
   temp_meta <- select_metadata(t="grid", c=city)
 
   # check if download failed
-  if (is.null(temp_meta)) { return(invisible(NULL)) } # nocov
+  check_downloaded_obj(temp_meta) # nocov
 
   # list paths of files to download
   file_url <- as.character(temp_meta$download_path2)
@@ -72,7 +72,7 @@ read_grid <- function(city = NULL,
   aop_sf <- download_data(url = file_url, progress_bar = showProgress)
 
   # check if download failed
-  if (is.null(aop_sf)) { return(invisible(NULL)) } # nocov
+  check_downloaded_obj(aop_sf) # nocov
 
   return(aop_sf)
 }
